<?php

namespace Litecms\Shippingtotal\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Shippingtotal\Models\ShippingTotal;

class ShippingTotalPolicy
{

    /**
     * Determine if the given user can view the shipping_total.
     *
     * @param UserPolicy $user
     * @param ShippingTotal $shipping_total
     *
     * @return bool
     */
    public function view(UserPolicy $user, ShippingTotal $shipping_total)
    {
        if ($user->canDo('shippingtotal.shipping_total.view') && $user->isAdmin()) {
            return true;
        }

        return $shipping_total->user_id == user_id() && $shipping_total->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shipping_total.
     *
     * @param UserPolicy $user
     * @param ShippingTotal $shipping_total
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shippingtotal.shipping_total.create');
    }

    /**
     * Determine if the given user can update the given shipping_total.
     *
     * @param UserPolicy $user
     * @param ShippingTotal $shipping_total
     *
     * @return bool
     */
    public function update(UserPolicy $user, ShippingTotal $shipping_total)
    {
        if ($user->canDo('shippingtotal.shipping_total.edit') && $user->isAdmin()) {
            return true;
        }

        return $shipping_total->user_id == user_id() && $shipping_total->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shipping_total.
     *
     * @param UserPolicy $user
     * @param ShippingTotal $shipping_total
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ShippingTotal $shipping_total)
    {
        return $shipping_total->user_id == user_id() && $shipping_total->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shipping_total.
     *
     * @param UserPolicy $user
     * @param ShippingTotal $shipping_total
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ShippingTotal $shipping_total)
    {
        if ($user->canDo('shippingtotal.shipping_total.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shipping_total.
     *
     * @param UserPolicy $user
     * @param ShippingTotal $shipping_total
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ShippingTotal $shipping_total)
    {
        if ($user->canDo('shippingtotal.shipping_total.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
