<?php

namespace Litecms\Shippingtotal\Providers;

use Illuminate\Support\ServiceProvider;

class ShippingtotalServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'shippingtotal');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'shippingtotal');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.shippingtotal', function ($app) {
            return $this->app->make('Litecms\Shippingtotal\Shippingtotal');
        });

                // Bind ShippingTotal to repository
        $this->app->bind(
            'Litecms\Shippingtotal\Interfaces\ShippingTotalRepositoryInterface',
            \Litecms\Shippingtotal\Repositories\Eloquent\ShippingTotalRepository::class
        );

        $this->app->register(\Litecms\Shippingtotal\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Shippingtotal\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.shippingtotal'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/shippingtotal.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/shippingtotal')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/shippingtotal')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
